@@ -845,19 +845,24 @@ void generate_items_for_action_option_combo_box (const gchar *preset_choice)
         the second one next to the current selection. If so, add headlines to the list to separate them from each other.
     */
     if (number_of_added_snotify_opts && number_of_added_action_opts) {
+        // Translation note: Do not translate "Startupnotify". This is for a context menu.
         add_inside_txt = _("Add Inside Startupnotify");
     }
     else if (number_of_added_action_opts && number_of_added_actions) {
         if (STREQ (ks.txt_fields[MENU_ELEMENT_TXT], "Execute")) {
+		    // Translation note: Do not translate "Execute". This is for a context menu.
             add_inside_txt = _("Add Inside Currently Selected Execute Action");
         }
         else if (STREQ (ks.txt_fields[MENU_ELEMENT_TXT], "Exit")) {
+		    // Translation note: Do not translate "Exit". This is for a context menu.
             add_inside_txt = _("Add Inside Currently Selected Exit Action");
         }
         else if (STREQ (ks.txt_fields[MENU_ELEMENT_TXT], "Restart")) {
+		    // Translation note: Do not translate "Restart". This is for a context menu.
             add_inside_txt = _("Add Inside Currently Selected Restart Action");
         }
         else { // SessionLogout
+		    // Translation note: Do not translate "SessionLogout". This is for a context menu.
             add_inside_txt = _("Add Inside Currently Selected SessionLogout Action");
         }
     }
@@ -879,7 +884,10 @@ void generate_items_for_action_option_combo_box (const gchar *preset_choice)
                                            ((number_of_added_actions) ? 
                                            number_of_added_action_opts : number_of_added_snotify_opts) + 2, 
                                            ACTION_OPTION_COMBO_ITEM, (number_of_added_actions) ? 
-                                           _("Add Additional Action") : _("Add Next to Startupnotify"), 
+                                           // Translation note: This is for a context menu
+                                           _("Add Additional Action") : 
+										   // Translation note: Translate "next to" as a phrase. A "Next" is not added to Startupnotify.
+										   _("Add Next to Startupnotify"), 
                                            -1);
     }
 
